@@ -10,6 +10,12 @@ use App::Translit::String;
 # Run.
 App::Translit::String->new->run;
 
+# Print version.
+sub VERSION_MESSAGE {
+       print "9.99\n";
+       exit 0;
+}
+
 # Output:
 # Usage: /tmp/vm3pgIQWej [-h] [-r] [-t table] [--version]
 #         string
